@@ -4,6 +4,7 @@ cv.glmnet=function(x,y,weights,offset=NULL,lambda=NULL,...,nfolds=10,foldid,type
   N=nrow(x)
   if(missing(weights))weights=rep(1.0,N)else weights=as.double(weights)
 ###Fit the model once to get dimensions etc of output
+  y=drop(y) # we dont like matrix responses unless we need them
   glmnet.object=glmnet(x,y,weights=weights,offset=offset,lambda=lambda,...)
   is.offset=glmnet.object$offset
   lambda=glmnet.object$lambda
@@ -22,7 +23,7 @@ cv.glmnet=function(x,y,weights,offset=NULL,lambda=NULL,...,nfolds=10,foldid,type
     if(is.matrix(y))y_sub=y[!which,]else y_sub=y[!which]
     if(is.offset)offset_sub=as.matrix(offset)[!which,]
     else offset_sub=NULL
-    outlist[[i]]=glmnet(x[!which,],y_sub,lambda=lambda,offset=offset_sub,weights=weights[!which],...)
+    outlist[[i]]=glmnet(x[!which,,drop=FALSE],y_sub,lambda=lambda,offset=offset_sub,weights=weights[!which],...)
   }
   ###What to do depends on the type and the model fit
   fun=paste("cv",class(glmnet.object)[[2]],sep=".")
@@ -31,7 +32,7 @@ cv.glmnet=function(x,y,weights,offset=NULL,lambda=NULL,...,nfolds=10,foldid,type
   cvsd=cvstuff$cvsd
   cvname=cvstuff$name
   
-out=list(lambda=lambda,cvm=cvm,cvsd=cvsd,cvup=cvm+cvsd,cvlo=cvm-cvsd,nzero=nz,name=cvname)
+out=list(lambda=lambda,cvm=cvm,cvsd=cvsd,cvup=cvm+cvsd,cvlo=cvm-cvsd,nzero=nz,name=cvname,glmnet.fit=glmnet.object)
   lamin=if(type=="auc")getmin(lambda,-cvm,cvsd)
   else getmin(lambda,cvm,cvsd)
   obj=c(out,as.list(lamin))
