@@ -1,9 +1,10 @@
-glmnet=function(x,y,family=c("gaussian","binomial","poisson","multinomial","cox"),weights,offset=NULL,alpha=1.0,nlambda=100,lambda.min=ifelse(nobs<nvars,5e-2,1e-4),lambda=NULL,standardize=TRUE,thresh=1e-4,dfmax=nvars+1,pmax=min(dfmax*1.2,nvars),exclude,penalty.factor=rep(1,nvars),maxit=100,HessianExact=FALSE,type=c("covariance","naive")){
+glmnet=function(x,y,family=c("gaussian","binomial","poisson","multinomial","cox"),weights,offset=NULL,alpha=1.0,nlambda=100,lambda.min.ratio=ifelse(nobs<nvars,1e-2,1e-4),lambda=NULL,standardize=TRUE,thresh=1e-4,dfmax=nvars+1,pmax=min(dfmax*1.2,nvars),exclude,penalty.factor=rep(1,nvars),maxit=100,HessianExact=FALSE,type=c("covariance","naive")){
 
 ### Prepare all the generic arguments, then hand off to family functions
   family=match.arg(family)
   this.call=match.call()
   nlam=as.integer(nlambda)
+  y=drop(y) # we dont like matrix responses unless we need them
   np=dim(x)
   nobs=as.integer(np[1])
   if(missing(weights))weights=rep(1,nobs)
@@ -21,8 +22,8 @@ glmnet=function(x,y,family=c("gaussian","binomial","poisson","multinomial","cox"
   isd=as.integer(standardize)
   thresh=as.double(thresh)
   if(is.null(lambda)){
-     if(lambda.min>=1)stop("lambda.min should be less than 1")
-    flmin=as.double(lambda.min)
+     if(lambda.min.ratio>=1)stop("lambda.min.ratio should be less than 1")
+    flmin=as.double(lambda.min.ratio)
     ulam=double(1)
   }
   else{
@@ -43,8 +44,8 @@ glmnet=function(x,y,family=c("gaussian","binomial","poisson","multinomial","cox"
   fit=switch(family,
     "gaussian"=elnet(x,is.sparse,ix,jx,y,weights,offset,type,alpha,nobs,nvars,jd,vp,ne,nx,nlam,flmin,ulam,thresh,isd,vnames),
     "poisson"=fishnet(x,is.sparse,ix,jx,y,weights,offset,type,alpha,nobs,nvars,jd,vp,ne,nx,nlam,flmin,ulam,thresh,isd,vnames,maxit),
-    "binomial"=lognet(x,is.sparse,ix,jx,y,weights,offset,type,alpha,nobs,nvars,jd,vp,ne,nx,nlam,flmin,ulam,thresh,isd,vnames,maxit,HessianExact,family),
-    "multinomial"=lognet(x,is.sparse,ix,jx,y,weights,offset,type,alpha,nobs,nvars,jd,vp,ne,nx,nlam,flmin,ulam,thresh,isd,vnames,maxit,HessianExact,family),
+    "binomial"=lognet(x,is.sparse,ix,jx,y,weights,offset,type,alpha,nobs,nvars,jd,vp,ne,nx,nlam,flmin,ulam,thresh,isd,vnames,maxit,!HessianExact,family),
+    "multinomial"=lognet(x,is.sparse,ix,jx,y,weights,offset,type,alpha,nobs,nvars,jd,vp,ne,nx,nlam,flmin,ulam,thresh,isd,vnames,maxit,!HessianExact,family),
     "cox"=coxnet(x,is.sparse,ix,jx,y,weights,offset,type,alpha,nobs,nvars,jd,vp,ne,nx,nlam,flmin,ulam,thresh,isd,vnames,maxit)
     )
     
